@@ -5,3 +5,7 @@
 from pathlib import Path
 
 HOME_DIR = f"{Path.home()}/.quark-engine/"
+SOURCE = "https://github.com/quark-engine/quark-rules"
+DIR_PATH = f"{HOME_DIR}quark-rules"
+
+Path(HOME_DIR).mkdir(parents=True, exist_ok=True)
