@@ -1,9 +1,18 @@
+# -*- coding: utf-8 -*-
+# This file is part of Quark-Engine - https://github.com/quark-engine/quark-engine
+# See the file 'LICENSE' for copying permission.
+
 from quark import __version__
 
 from quark.utils.colors import bold, lightyellow, lightblue
 
 
 def logo():
+    """
+    Output our amazing logo
+
+    :return: None
+    """
     print(
         bold(
             lightyellow(
@@ -20,8 +29,8 @@ def logo():
         + bold(
             lightblue(
                 """
-            An Obfuscation-Neglect Android Malware Scoring System
-            """
+                An Obfuscation-Neglect Android Malware Scoring System
+                """
             ),
         ),
     )
